//--------------------------------------------------------------
// File     : stm32_ub_icpwm_tim5.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_ICPWM_TIM5_H
#define __STM32F4_UB_ICPWM_TIM5_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"


//--------------------------------------------------------------
// InputCapture Pin (PWM-Messung)
// der Name dient hier nur zur leichteren Lesbarkeit
//--------------------------------------------------------------
#define ICPWM_T5_PA0  0   // PWM-Messung per TIM5 an PA0



//--------------------------------------------------------------
// Input-Capture Einstellungen (Frequenz vom Timer5)
//
// Grundfrequenz = 2*APB1 (APB1=42MHz) => TIM_CLK=84MHz
// prescale  : 0 bis 0xFFFF
//
// T5_Frq = TIM_CLK/(vorteiler+1)
//--------------------------------------------------------------
#define  ICPWM_TIM5_PRESCALE  83     // prescaler => (83 => T5_Frq = 1 MHz)



//--------------------------------------------------------------
// Struktur vom InputCapture Kanals (zur PWM-Messung)
//--------------------------------------------------------------
typedef struct {
  const uint8_t IC_NAME;       // Name
  const uint8_t CHANNEL;       // Channel [1...2]
  GPIO_TypeDef* IC_PORT;       // Port
  const uint16_t IC_PIN;       // Pin
  const uint32_t IC_CLK;       // Clock
  const uint8_t IC_SOURCE;     // Source
}ICPWM_TIM5_t;


//--------------------------------------------------------------
// interne Struktur
//--------------------------------------------------------------
typedef struct {
  uint16_t frq;       // FRQ-Wert
  uint16_t duty;      // DutyCycle
}ICPWM_TIM5_Var_t;


//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_ICPWM_TIM5_Init(void);
uint16_t UB_ICPWM_TIM5_ReadFRQ(void);
uint16_t UB_ICPWM_TIM5_ReadDUTY(void);




//--------------------------------------------------------------
#endif // __STM32F4_UB_ICPWM_TIM5_H
